@@ -20,6 +20,7 @@ import (
 	"fmt"
 	"os"
 	"strings"
+	"time"
 
 	apko_types "chainguard.dev/apko/pkg/build/types"
 	"github.com/chainguard-dev/clog"
@@ -51,6 +52,11 @@ func addTestFlags(fs *pflag.FlagSet, flags *TestFlags) {
 	fs.StringSliceVar(&flags.ExtraTestPackages, "test-package-append", []string{}, "extra packages to install for each of the test environments")
 	fs.BoolVar(&flags.Remove, "rm", true, "clean up intermediate artifacts (e.g. container images, temp dirs)")
 	fs.BoolVar(&flags.IgnoreSignatures, "ignore-signatures", false, "ignore repository signature verification")
+	fs.StringVar(&flags.CPU, "cpu", "", "default CPU resources to use for tests")
+	fs.StringVar(&flags.CPUModel, "cpumodel", "", "default CPU model to use for tests")
+	fs.StringVar(&flags.Disk, "disk", "", "disk size to use for tests")
+	fs.StringVar(&flags.Memory, "memory", "", "default memory resources to use for tests")
+	fs.DurationVar(&flags.Timeout, "timeout", 0, "default timeout for tests")
 }
 
 // TestFlags holds all parsed test command flags
@@ -73,6 +79,11 @@ type TestFlags struct {
 	ExtraTestPackages []string
 	Remove            bool
 	IgnoreSignatures  bool
+	CPU               string
+	CPUModel          string
+	Memory            string
+	Disk              string
+	Timeout           time.Duration
 }
 
 // ParseTestFlags parses test flags from the provided args and returns a TestFlags struct
@@ -89,6 +100,66 @@ func ParseTestFlags(args []string) (*TestFlags, []string, error) {
 	return flags, fs.Args(), nil
 }
 
+// TestOptions converts TestFlags into a slice of build.TestOption
+// This includes all core test options that are directly derived from the flags.
+func (flags *TestFlags) TestOptions(ctx context.Context, args ...string) ([]build.TestOption, error) {
+	r, err := getRunner(ctx, flags.Runner, flags.Remove)
+	if err != nil {
+		return nil, err
+	}
+
+	options := []build.TestOption{
+		build.WithTestWorkspaceDir(flags.WorkspaceDir),
+		build.WithTestCacheDir(flags.CacheDir),
+		build.WithTestCacheSource(flags.CacheSource),
+		build.WithTestPackageCacheDir(flags.ApkCacheDir),
+		build.WithTestExtraKeys(flags.ExtraKeys),
+		build.WithTestExtraRepos(flags.ExtraRepos),
+		build.WithExtraTestPackages(flags.ExtraTestPackages),
+		build.WithTestRunner(r),
+		build.WithTestEnvFile(flags.EnvFile),
+		build.WithTestDebug(flags.Debug),
+		build.WithTestDebugRunner(flags.DebugRunner),
+		build.WithTestInteractive(flags.Interactive),
+		build.WithTestRemove(flags.Remove),
+		build.WithTestIgnoreSignatures(flags.IgnoreSignatures),
+		build.WithTestCPU(flags.CPU),
+		build.WithTestCPUModel(flags.CPUModel),
+		build.WithTestMemory(flags.Memory),
+		build.WithTestDisk(flags.Disk),
+		build.WithTestTimeout(flags.Timeout),
+	}
+
+	if len(args) > 0 {
+		options = append(options, build.WithTestConfig(args[0]))
+	}
+	if len(args) > 1 {
+		options = append(options, build.WithTestPackage(args[1]))
+	}
+
+	if flags.SourceDir != "" {
+		options = append(options, build.WithTestSourceDir(flags.SourceDir))
+	}
+
+	for i := range flags.PipelineDirs {
+		options = append(options, build.WithTestPipelineDir(flags.PipelineDirs[i]))
+	}
+	options = append(options, build.WithTestPipelineDir(BuiltinPipelineDir))
+
+	if auth, ok := os.LookupEnv("HTTP_AUTH"); !ok {
+		// Fine, no auth.
+	} else if parts := strings.SplitN(auth, ":", 4); len(parts) != 4 {
+		return nil, fmt.Errorf("HTTP_AUTH must be in the form 'basic:REALM:USERNAME:PASSWORD' (got %d parts)", len(parts))
+	} else if parts[0] != "basic" {
+		return nil, fmt.Errorf("HTTP_AUTH must be in the form 'basic:REALM:USERNAME:PASSWORD' (got %q for first part)", parts[0])
+	} else {
+		domain, user, pass := parts[1], parts[2], parts[3]
+		options = append(options, build.WithTestAuth(domain, user, pass))
+	}
+
+	return options, nil
+}
+
 func test() *cobra.Command {
 	// Create TestFlags struct (defaults are set in addTestFlags)
 	flags := &TestFlags{}
@@ -101,54 +172,10 @@ func test() *cobra.Command {
 		Args:    cobra.MinimumNArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			ctx := cmd.Context()
-			r, err := getRunner(ctx, flags.Runner, flags.Remove)
-			if err != nil {
-				return err
-			}
-
 			archs := apko_types.ParseArchitectures(flags.Archstrs)
-			options := []build.TestOption{
-				build.WithTestWorkspaceDir(flags.WorkspaceDir),
-				build.WithTestCacheDir(flags.CacheDir),
-				build.WithTestCacheSource(flags.CacheSource),
-				build.WithTestPackageCacheDir(flags.ApkCacheDir),
-				build.WithTestExtraKeys(flags.ExtraKeys),
-				build.WithTestExtraRepos(flags.ExtraRepos),
-				build.WithExtraTestPackages(flags.ExtraTestPackages),
-				build.WithTestRunner(r),
-				build.WithTestEnvFile(flags.EnvFile),
-				build.WithTestDebug(flags.Debug),
-				build.WithTestDebugRunner(flags.DebugRunner),
-				build.WithTestInteractive(flags.Interactive),
-				build.WithTestRemove(flags.Remove),
-				build.WithTestIgnoreSignatures(flags.IgnoreSignatures),
-			}
-
-			if len(args) > 0 {
-				options = append(options, build.WithTestConfig(args[0]))
-			}
-			if len(args) > 1 {
-				options = append(options, build.WithTestPackage(args[1]))
-			}
-
-			if flags.SourceDir != "" {
-				options = append(options, build.WithTestSourceDir(flags.SourceDir))
-			}
-
-			for i := range flags.PipelineDirs {
-				options = append(options, build.WithTestPipelineDir(flags.PipelineDirs[i]))
-			}
-			options = append(options, build.WithTestPipelineDir(BuiltinPipelineDir))
-
-			if auth, ok := os.LookupEnv("HTTP_AUTH"); !ok {
-				// Fine, no auth.
-			} else if parts := strings.SplitN(auth, ":", 4); len(parts) != 4 {
-				return fmt.Errorf("HTTP_AUTH must be in the form 'basic:REALM:USERNAME:PASSWORD' (got %d parts)", len(parts))
-			} else if parts[0] != "basic" {
-				return fmt.Errorf("HTTP_AUTH must be in the form 'basic:REALM:USERNAME:PASSWORD' (got %q for first part)", parts[0])
-			} else {
-				domain, user, pass := parts[1], parts[2], parts[3]
-				options = append(options, build.WithTestAuth(domain, user, pass))
+			options, err := flags.TestOptions(ctx, args...)
+			if err != nil {
+				return fmt.Errorf("getting test options from flags: %w", err)
 			}
 
 			return TestCmd(cmd.Context(), archs, options...)
