@@ -26,8 +26,8 @@ import (
 
 func SbomLinter(ctx context.Context, _ *config.Configuration, pkgname string, fsys fs.FS) error {
 	return AllPaths(ctx, pkgname, fsys,
-		func(path string) bool {
-			return filepath.Dir(path) == "var/lib/db/sbom" && !strings.HasSuffix(path, ".spdx.json")
+		func(path string, d fs.DirEntry) bool {
+			return !d.IsDir() && filepath.Dir(path) == "var/lib/db/sbom" && !strings.HasSuffix(path, ".spdx.json")
 		},
 		func(pkgname string, paths []string) string {
 			return fmt.Sprintf("%s writes to var/lib/db/sbom", pkgname)
