@@ -99,6 +99,12 @@ func New(opts ...Option) renovate.Renovator {
 		// Find our main pipeline YAML node.
 		pipelineNode, err := renovate.NodeFromMapping(rc.Configuration.Root().Content[0], "pipeline")
 		if err != nil {
+			// The main pipeline doesn't exist. This is valid for empty virtual and metapackages so
+			// we will just return early instead of throwing an error
+			if strings.Contains(err.Error(), "not found in mapping") {
+				log.Infof("no main pipeline found, will not cache any artifacts")
+				return nil
+			}
 			return err
 		}
 
